# Full example

Here is a full working example with JWT authentication to help get you started.

!!! warning
    Notice that **SECRET** should be changed to a strong passphrase.
    Insecure passwords may give attackers full access to your database.

## SQLAlchemy

[Open ↗️](https://replit.com/@frankie567/fastapi-users-sqlalchemy)

<iframe frameborder="0" width="100%" height="500px" src="https://replit.com/@frankie567/fastapi-users-sqlalchemy?embed=true"></iframe>


## MongoDB

[Open ↗️](https://replit.com/@frankie567/fastapi-users-mongodb)

<iframe frameborder="0" width="100%" height="500px" src="https://replit.com/@frankie567/fastapi-users-mongodb?embed=true"></iframe>

## Tortoise ORM

[Open ↗️](https://replit.com/@frankie567/fastapi-users-tortoise)

<iframe frameborder="0" width="100%" height="500px" src="https://replit.com/@frankie567/fastapi-users-tortoise?embed=true"></iframe>

## Ormar

[Open ↗️](https://replit.com/@frankie567/fastapi-users-ormar)

<iframe frameborder="0" width="100%" height="500px" src="https://replit.com/@frankie567/fastapi-users-ormar?embed=true"></iframe>

## What now?

You're ready to go! Be sure to check the [Usage](../usage/routes.md) section to understand how to work with **FastAPI Users**.
